@@ -17,4 +17,4 @@ def visualize_table_vertically_with_colors(table, collation):
     for witness in collation.witnesses:
         sigli.append(witness.sigil)
     x = Table(header_row=sigli, rows=rows)
-    return HTML(str(x)).data
+    return str(x)
